require 'helper'
require 'json'
require 'touggsl'
require 'touggsl_helper'
require './lib/touggsl/customer'
class TestClient < Test::Unit::TestCase
  

  def setup

Time.stubs(:now).returns(Time.mktime(2013,11,03))
    stub_request(:get, "http://touggweb-001.superlogica.net/financeiro/atual/auth/post").
            to_return(:status => 401, :body => "", :headers => {'Set-Cookie' => "xpto"})

    url = "http://touggweb-001.superlogica.net/financeiro/atual/auth/post"
    WebMock.stub_request(:post,url).
                  with(:body => {username: 'jack', password: 'secret'}).
                  to_return(:body => TouggHelper.json_success_auth)

    auth = Touggsl::Auth
    auth.login("jack", "secret")
    @client = Touggsl::Customer.new(auth)
  end

  def test_client_should_have_a_auth
    assert_not_nil @client.auth
  end

  def test_create_new_client

    stub_request(:post, "http://touggweb-001.superlogica.net/financeiro/atual/sacados/put").
  with(:body => "ST_SINCRO_SAC=0303030&ST_NOME_SAC=Jack&ST_NOMEREF_SAC=Tougg&ST_EMAIL_SAC=0&ST_DIAVENCIMENTO_SAC=0&ST_ENDERECO_SAC=&ST_ESTADO_SAC=&ST_CIDADE_SAC=&ST_CEP_SAC=&ST_NUMERO_SAC=&ST_BAIRRO_SAC=",
       :headers => {'Cookie'=>'xpto'}).
  to_return(:status => 200, :body => TouggHelper.success_create_client, :headers => {})
    

   client_created = @client.create_new_client("0303030", "Jack", "Tougg") 
   assert_equal "200", client_created
  end

  def test_hiring_plan

  stub_request(:post, "http://touggweb-001.superlogica.net/financeiro/atual/planosclientes/put").
            with(:body => "PLANOS[1][identificador]=10&PLANOS[1][ID_PLANO_PLA]=2&PLANOS[1][DT_CONTRATO_PLC]=11%2F03%2F2013&PLANOS[1][ST_IDENTIFICADOR_PLC]=1000&PLANOS[1][FL_NOTIFICARCLIENTE]=0&PLANOS[1][QUANT_PARCELAS_ADESAO]=1&PLANOS[1][ID_FORMAPAGAMENTO_RECB]=0",
                 :headers => {'Cookie'=>'xpto'}).
            to_return(:status => 200, :body =>  TouggHelper::contratar_plano,:headers => {})
    
    plan_id = 2
    client_id = 10
    contract_id = 1000
    forma_pagamento = 0
    plan = @client.hiring_plan(plan_id, client_id, contract_id, forma_pagamento)
    assert_equal "http://touggweb-001.superlogica.net/clients/financeiro/publico/cobranca?id=59&publickey=ce4dc5b51dc6b45d15de28c2ba181e3323540adb", plan
  end

  def test_try_hiring_plan_again
    stub_request(:post, "http://touggweb-001.superlogica.net/financeiro/atual/planosclientes/put").
            with(:body => "PLANOS[1][identificador]=10&PLANOS[1][ID_PLANO_PLA]=2&PLANOS[1][DT_CONTRATO_PLC]=11%2F03%2F2013&PLANOS[1][ST_IDENTIFICADOR_PLC]=1000&PLANOS[1][FL_NOTIFICARCLIENTE]=0&PLANOS[1][QUANT_PARCELAS_ADESAO]=1&PLANOS[1][ID_FORMAPAGAMENTO_RECB]=0",
                 :headers => {'Cookie'=>'xpto'}).
            to_return(:status => 200, :body =>  TouggHelper::hiring_plan_again, :headers => {})

    plan_id = 2
    client_id = 10
    contract_id = 1000
    forma_pagamento = 0
    plan = @client.hiring_plan(plan_id, client_id, contract_id, forma_pagamento)
    assert_equal "Plano ja contratado ou ID do plano informado nao existe", plan
  end

  def test_get_inadimplmentes
   stub_request(:get, "http://touggweb-001.superlogica.net/financeiro/atual/inadimplencia/index").
           with(:body => "posicaoEm=11%2F03%2F2013").
      to_return(:status => 200, :body => TouggHelper.inadimplementes, :headers => {}) 
    
   clients = @client.get_all_inadimplentes
    
    assert_not_nil clients
    assert_equal 4, clients.size
    assert_equal "40", clients[0].client_id
    segunda_via_cobranca = "http://touggweb-001.superlogica.net-001.superlogica.net/clients/extranet/cobranca/id/21?filename=touggweb-001&accesskey=e479383dd2aa47be5f1e81237729be3c&identificador=661"
    assert_equal segunda_via_cobranca, clients[0].segunda_via_cobranca
  end

  def test_get_link_2via
    stub_request(:post, "http://touggweb-001.superlogica.net/financeiro/atual/cobranca/index").
    with(:body => "identificador=980", :headers => {'Cookie'=>'xpto'}).
    to_return(:status => 200, :body => TouggHelper.success_link_2via_normal_client, :headers => {})

    return_link = @client.link_2via_normal_client(980)
    link = "http://touggweb-001.superlogica.net-001.superlogica.net/clients/extranet/cobranca/id/62?filename=touggweb-001&accesskey=edf2e76e3c290f7e2a0b49da283a0703&identificador=980"
    assert_equal link, return_link
  end

end
